@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
 from .dunning import *
@@ -15,7 +15,9 @@ def register():
         CreateDunningStart,
         ProcessDunningStart,
         Party,
+        PartyDunningProcedure,
         Configuration,
+        ConfigurationDefaultDunningProcedure,
         MoveLine,
         module='account_dunning', type_='model')
     Pool.register(
